<?php
///////////////////////////////////////////////////////////////////////////

const ECODE_QUERY_LIMIT_EXCEEDED = 31;
const ECODE_MALLFORMED_REPLAY = 101;

const DEVICE_VER = 2;

class SSTV
{
    public static $SERVER = 'fromhome.tv';
}

const SSTV_LOGIN_URL =
    'http://%s/api/json/login?login=%s&pass=%s&settings=all&device=dune&tz=%s&lang=%s&forplay=%s';

const SSTV_CHANNEL_LIST_URL =
    'http://%s/api/json/channel_list?%s=%s';

const SSTV_SET_SETTING_URL =
    'http://%s/api/json/settings_set?%s=%s&var=%s&val=%s';

const SSTV_CHANGE_PCODE_URL =
    'http://%s/api/json/settings_set?%s=%s&var=pcode&old_code=%s&new_code=%s&confirm_code=%s&ar=%s';

const SSTV_CHANGE_AR_URL =
    'http://%s/api/json/settings_set?%s=%s&var=ar&val=%s&old_code=%s';

const SSTV_EPG_URL =
    'http://%s/api/json/epg?%s=%s&cid=%s&day=%s';

const SSTV_GET_URL_URL =
    'http://ts://%s/api/json/get_url?%s=%s&cid=%s';

const SSTV_VOD_LIST_URL_PREFIX =
    'http://%s/api/json/vod_list?%s=%s&type=%s&page=%s&nums=%s';

const SSTV_VOD_INFO_URL =
    'http://%s/api/json/vod_info?%s=%s&id=%s';

const SSTV_VOD_FAVLIST_URL =
    'http://%s/api/json/vod_favlist?%s=%s';

const SSTV_VOD_GENRES_URL =
    'http://%s/api/json/vod_genres?%s=%s';

const SSTV_VOD_FAVADD_URL=
    'http://%s/api/json/vod_favadd?%s=%s&id=%s';

const SSTV_VOD_FAVSUB_URL=
    'http://%s/api/json/vod_favsub?%s=%s&id=%s';

const SSTV_VOD_GET_URL_URL =
    'http://mp4://%s/api/json/vod_geturl?%s=%s&fileid=%s';

const SSTV_ENTER_PAY_CODE_URL =
    'http://%s/api/json/enter_pay_code?%s=%s&code=%s';

const SSTV_FAVORITES_URL =
    'http://%s/api/json/favorites?%s=%s';

const SSTV_FAVORITES_SET_URL =
    'http://%s/api/json/favorites_set?%s=%s&place=%s&cid=%s';

const SSTV_CHANNEL_INFO_URL =
    'http://%s/api/json/channel_info?%s=%s&cid=%s';

const SSTV_ARCHIVE_ID = 'vdali_icons';

class SStvSession
{
    private $http_opts = null;

    private $logged_in = false;
    private $sid_name = null;
    private $sid = null;

    private $login_incorrect = false;

    private $account = null;
    private $services = null;
    private $settings = null;

    private $channel_list = null;
    private $favorites = null;

    private $unset_login_listener = null;

    private $apply_run_perm = false;
    private $lang = null;
    private $lang_suffix = '';
    private $tz = null;

    ///////////////////////////////////////////////////////////////////////

    public function __construct($unset_login_listener)
    {
        $this->http_opts = array (
            CURLOPT_FOLLOWLOCATION  => true,
            CURLOPT_MAXREDIRS       => 10,
            CURLOPT_COOKIEFILE      => '/tmp/vdali.cookies',
            CURLOPT_COOKIEJAR       => '/tmp/vdali.cookies'
        );

        $l = null;
        CrackDuneConfig($l, $this->tz);
        $this->lang = SelectLang($l);

    	switch($l)
    	{
		case 'russian'	: define('SSTV_ARCHIVE_URL_PREFIX', 'http://' . SSTV::$SERVER . '/arc/lang/rus', true); $this->lang_suffix = '_rus'; break;
		case 'italian'	: define('SSTV_ARCHIVE_URL_PREFIX', 'http://' . SSTV::$SERVER . '/arc/lang/ita', true); $this->lang_suffix = '_ita'; break;
		case 'french'	: define('SSTV_ARCHIVE_URL_PREFIX', 'http://' . SSTV::$SERVER . '/arc/lang/fr',  true); $this->lang_suffix = '_fr' ; break;
    	case 'german'	: define('SSTV_ARCHIVE_URL_PREFIX', 'http://' . SSTV::$SERVER . '/arc/lang/ger', true); $this->lang_suffix = '_ger'; break;
    	case 'spanish'	: define('SSTV_ARCHIVE_URL_PREFIX', 'http://' . SSTV::$SERVER . '/arc/lang/spa', true); $this->lang_suffix = '_spa'; break;
		case 'english'	: define('SSTV_ARCHIVE_URL_PREFIX', 'http://' . SSTV::$SERVER . '/arc/lang/eng', true); $this->lang_suffix = '_eng'; break;
    	default		: define('SSTV_ARCHIVE_URL_PREFIX', 'http://' . SSTV::$SERVER . '/arc', true); $this->lang_suffix = ''; break;
	    }

        $this->unset_login_listener = $unset_login_listener;
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_channel_list()
    { return $this->channel_list; }

    public function get_account()
    { return $this->account; }

    public function get_settings()
    { return $this->settings; }

    public function get_tz()
    { return $this->tz; }

    public function get_lang()
    { return $this->lang; }

    ///////////////////////////////////////////////////////////////////////

    public function is_login_incorrect()
    { return $this->login_incorrect; }

    public function is_logged_in()
    { return $this->logged_in; }

    public function unset_login()
    {
        $this->logged_in = false;
        $this->sid_name = null;
        $this->sid = null;

        $this->account = null;
        $this->services = null;

        $this->settings = null;

        $this->channel_list = null;
    }

    public function logout()
    {
        $this->unset_login_listener->unset_login();
    }

    ///////////////////////////////////////////////////////////////////////

    private function fetch_document($url)
    {
        $doc = HD::http_get_document($url, $this->http_opts);

        // assert($doc != null).

        return $doc;
    }

    public function api_call($url, $silent=true)
    {
        for (;;)
        {
            $str = $this->fetch_document($url);

            if (!$silent)
                echo("Document:\n$str\n");

            $reply = json_decode($str);
            if ($reply === null)
                throw new SStvException('Invalid data received from server', ECODE_MALLFORMED_REPLAY);

            if (isset($reply->error))
            {
                $ecode = intval($reply->error->code);

                if ($ecode === ECODE_QUERY_LIMIT_EXCEEDED)
                {
                    hd_print('API: query limit exceeded');
                    continue;
                }

                hd_print("API error: URL '$url' " .
                    "returned error with code=$ecode, msg=" .
                    $reply->error->message . '.');

                throw new SStvException(
                    $reply->error->message, $ecode);
            }

            break;
        }

        return $reply;
    }

    ///////////////////////////////////////////////////////////////////////

    public function dune_api_exception($e, $def_caption, $is_playback)
    {
        $is_sstv_error = ($e instanceof SStvException);
        if (!$is_sstv_error)
        {
            hd_print('General exception: ' . $e->getMessage());
            $title = !$is_playback ? $this->lang->err :
                $this->lang->err_internet_connection;
            $text_lines = $is_playback ? array() :
                $this->lang->err_internet_connection_failed;
            return new DuneException(
                $def_caption, -1,
                ActionFactory::show_error(false, $title, $text_lines));
        }
        hd_print('API exception: ' .
            'code=' . $e->getCode() . ', message=' . $e->getMessage());

        $ecode = $e->getCode();
        $fatal = $ecode == 5 || $ecode == 6 ||
            $ecode == 11 || $ecode == 12 || $ecode == 13 || $ecode == 98;

        if ($fatal)
            $this->logout();

        if ($ecode == 2 || $ecode == 4)
        {
            $this->login_incorrect = true;

            $title = !$is_playback ? $this->lang->err :
                $this->lang->err_login;
            $text_lines = $is_playback ? array() :
                array($this->lang->err_login);
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error($fatal, $title, $text_lines));
        }

        if ($ecode == 12)
        {
            $title = !$is_playback ? $this->lang->err :
                $this->lang->err_12;
            $text_lines = $is_playback ? array() :
                array($this->lang->err,
                    $this->lang->err_12);
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error($fatal, $title, $text_lines));
        }

        if ($ecode == 11)
        {
            $title = !$is_playback ? $this->lang->err :
                $this->lang->err_11;
            $text_lines = $is_playback ? array() :
                array($this->lang->err_11);
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error($fatal, $title, $text_lines));
        }

        if ($ecode == 19)
        {
            $title = !$is_playback ? $this->lang->err :
                $this->lang->err_pcode;
            $text_lines = $is_playback ? array() :
                array($this->lang->err_pcode);
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error($fatal, $title, $text_lines));
        }

        if ($ecode == 98)
        {
            $title = !$is_playback ? $this->lang->err :
                $this->lang->err_pluginver;
            $text_lines = $is_playback ? array() :
                array($this->lang->err_pluginver);
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error($fatal, $title, $text_lines));
        }

        if ($ecode == 99)
        {
            $title = !$is_playback ? $this->lang->err :
                $this->lang->err_pchannel;
            $text_lines = $is_playback ? array() :
                array($this->lang->err_pchannel);
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error(true, $title, $text_lines));
        }

        if ($ecode == 100)
        {
            $title = !$is_playback ? $this->lang->err :
                $this->lang->err_stream;
            $text_lines = $is_playback ? array() :
                array($this->lang->err_stream);
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error(true, $title, $text_lines));
        }

        if ($ecode == ECODE_MALLFORMED_REPLAY)
        {
            $title = !$is_playback ? $this->lang->err :
                $this->lang->err_stream;
            $text_lines = $this->lang->err_mallformed_replay;
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error(false, $title, $text_lines));
        }

        $title = !$is_playback ? $this->lang->err : $e->getMessage();
        $text_lines = $is_playback ? array() :
            array('Description: ' . $e->getMessage(),
                'Error code: ' . $ecode);
        return new DuneException(
            $def_caption, $ecode,
            ActionFactory::show_error($fatal, $title, $text_lines));
    }

    ///////////////////////////////////////////////////////////////////////

    public function api_vod_favadd($movie_id)
    {
        $this->check_logged_in();

        try
        {
            $this->api_call(
                sprintf(
                    SSTV_VOD_FAVADD_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid,
                    $movie_id));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'VOD favadd failed.', false);
        }
    }

    public function api_vod_favsub($movie_id)
    {
        $this->check_logged_in();

        try
        {
            $this->api_call(
                sprintf(
                    SSTV_VOD_FAVSUB_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid,
                    $movie_id));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'VOD favadd failed.', false);
        }
    }

    public function api_vod_info($movie_id)
    {
        $this->check_logged_in();

        try
        {
            $doc = $this->api_call(
                sprintf(
                    SSTV_VOD_INFO_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid,
                    $movie_id));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'VOD info failed.', false);
        }

        if (!isset($doc->film))
            throw new Exception('Invalid data received from server');

        $movie = new Movie($movie_id);

        $poster_url = 'http://' . SSTV::$SERVER . $doc->film->poster;

        $movie->set_data(
            $doc->film->name,
            $doc->film->name_orig,
            $doc->film->description,
            $poster_url,
            $doc->film->lenght,
            $doc->film->year,
            $doc->film->director,
            $doc->film->scenario,
            $doc->film->actors,
            $doc->film->genre_str,
            $doc->film->rate_imdb,
            $doc->film->rate_kinopoisk,
            $doc->film->rate_mpaa,
            $doc->film->country,
            $doc->film->budget);

        foreach ($doc->film->videos as $file)
        {
            $playback_url =
                sprintf(SSTV_VOD_GET_URL_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid,
                    $file->id);

            $movie->add_series_data(
                $file->id,
                $file->title,
                $playback_url,
                false);
        }

        return $movie;
    }

    public function api_get_stream_url($playback_url)
    {
        $this->check_logged_in();

        if (substr($playback_url, 0, 12) === 'http://ts://')
            $playback_url = 'http://' . substr($playback_url, 12);
        else if (substr($playback_url, 0, 13) === 'http://mp4://')
            $playback_url = 'http://' . substr($playback_url, 13);

        try
        {
            $doc = $this->api_call($playback_url);
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'Stream url request failed.',
                true);
        }

        if (!isset($doc->url))
            throw new Exception('Get_url failed, no urlset.');

        $url = $doc->url;
        if ($url == 'protected')
            throw new DuneException(
                $this->lang->err_pchannel, 99,
                ActionFactory::show_error(true, $this->lang->err_pcode, array()));

        if (!isset($doc->sstp))
            throw new Exception('Get_url failed, no sstp protocol set.');

        $sstp = $doc->sstp;
        $s_ip = $sstp->ip;
        $s_port = $sstp->port;
        $s_login = $sstp->login;
        $s_key = $sstp->key;

        $ss_bin_path = DuneSystem::$properties['install_dir_path'] . '/bin';

        if ($this->apply_run_perm == false)
        {
            $this->apply_run_perm = true;
            $cmd = 'chmod +x '. $ss_bin_path . '/*';
            $s = shell_exec($cmd);
            if (!empty($s))
                hd_print("$cmd - $s");
        }

        $cmd = $ss_bin_path . "/play.sh $ss_bin_path $s_ip $s_port $s_login $s_key > /tmp/ss.log";
        $s = shell_exec($cmd);
        if (!empty($s))
            hd_print("$cmd - $s");
        $url = 'http://127.0.0.1:5000';
        hd_print("Play URL: $url, ip=$s_ip, port=$s_port, login=$s_login, key=$s_key");
        return $url;
    }

    public function api_set_setting($name, $value)
    {
        $this->check_logged_in();

        try
        {
            $doc = $this->api_call(
                sprintf(
                    SSTV_SET_SETTING_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid,
                    $name, $value),
                false);
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e, 'Set setting failed.', false);
        }

        $this->settings->{$name}->value = $value;
    }

    public function api_change_pcode($old_code, $new_code, $confirm_code, $ar)
    {
        $this->check_logged_in();

        try
        {
            $doc = $this->api_call(
                sprintf(
                    SSTV_CHANGE_PCODE_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid,
                    $old_code, $new_code, $confirm_code, $ar),
                false);
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'Change protect code failed.', false);
        }
    }

    public function api_change_ar($old_code, $ar)
    {
        $this->check_logged_in();

        try
        {
            $doc = $this->api_call(
                sprintf(
                    SSTV_CHANGE_AR_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid,
                    $ar, $old_code),
                false);
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'Change age rating failed.', false);
        }
    }

    private function api_vod_list($type, $query, $genre, $page, $nums)
    {
        $this->check_logged_in();

        $url = sprintf(SSTV_VOD_LIST_URL_PREFIX,
            SSTV::$SERVER, $this->sid_name, $this->sid,
            $type, $page, $nums);
        if ($genre !== null)
            $url .= "&genre=$genre";
        if ($query !== null)
            $url .= "&query=$query";

        try
        {
            $doc = $this->api_call($url);
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'VOD list request failed.', false);
        }

        return $doc;
    }

    public function api_vod_list_last($page, $nums)
    {
        return $this->api_vod_list('last', null, null, $page, $nums);
    }

    public function api_vod_list_best($page, $nums)
    {
        return $this->api_vod_list('best', null, null, $page, $nums);
    }

    public function api_vod_list_search($query, $page, $nums)
    {
        return $this->api_vod_list('text', $query, null, $page, $nums);
    }

    public function api_vod_list_genres($genre, $page, $nums)
    {
        return $this->api_vod_list('last', null, $genre, $page, $nums);
    }

    public function api_vod_favlist()
    {
        $this->check_logged_in();

        try
        {
            $doc = $this->api_call(
                sprintf(SSTV_VOD_FAVLIST_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'VOD favlist request failed.', false);
        }

        return $doc;
    }

    public function api_vod_genres()
    {
        $this->check_logged_in();

        try
        {
            $doc = $this->api_call(
                sprintf(SSTV_VOD_GENRES_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'VOD genres request failed.', false);
        }

        return $doc;
    }

    private function api_login($user_name, $password, $for_play)
    {
        if (!is_numeric($this->tz))
            throw new DuneException($this->lang->err, -1,
                ActionFactory::show_error(false, $this->lang->err,
                $this->lang->wrong_timezone));

        try
        {
            $doc = $this->api_call(
                sprintf(
                    SSTV_LOGIN_URL, SSTV::$SERVER,
                    $user_name,
                    $password,
                    $this->tz,
                    $this->lang->short_name,
					$for_play
					),
                false);
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e, 'Login failed.', false);
        }

        $this->logged_in = true;
        $this->sid = $doc->sid;
        $this->sid_name = $doc->sid_name;
        $this->login_incorrect = false;
        $this->account = $doc->account;
        $this->services = $doc->services;
        $this->settings = $doc->settings;

        if (isset($this->account) && isset($this->account->device_ver) &&
            DEVICE_VER < $this->account->device_ver)
            throw $this->dune_api_exception(new SStvException('', 98),
                '', false);
    }

    private function api_channel_list()
    {
        try
        {
            $doc = $this->api_call(
                sprintf(
                    SSTV_CHANNEL_LIST_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'Channel list request failed.', false);
        }

        $this->channel_list = $doc;
    }

    public function api_enter_pay_code($code)
    {
        $this->check_logged_in();
        try
        {
            $doc = $this->api_call(
                sprintf(
                    SSTV_ENTER_PAY_CODE_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid, $code));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'Error submitting PIN-code.', false);
        }
		return $doc;
    }

    public function api_favorites()
    {
        $this->check_logged_in();
	
        if($this->favorites != null)
            return $this->favorites;

        try
        {
            $doc = $this->api_call(
                sprintf(
                    SSTV_FAVORITES_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid));

            // fix empty favorites bug
            if(!isset($doc->favorites->item))
            {
                $doc->favorites->{'item'} = array();
                $doc->favorites->item[0]->{'place'} = 1;
                $doc->favorites->item[0]->{'channel_id'} = 0;
            }
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'Favorites list request failed.', false);
        }

        $this->favorites = $doc;
        return $doc;
    }

    public function api_favorites_set($position, $channel)
    {
        $this->check_logged_in();
	
		if(!$this->favorites)
			$this->api_favorites();

        try
        {
            $doc = $this->api_call(
                sprintf(
                    SSTV_FAVORITES_SET_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid, $position, $channel));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'Favorites update request failed.', false);
        }
		$this->favorites = null;

    }
    
    public function api_channel_info($channel)
    {
        $this->check_logged_in();

        try
        {
            $doc = $this->api_call(
                sprintf(
                    SSTV_CHANNEL_INFO_URL, SSTV::$SERVER,
                    $this->sid_name, $this->sid, $channel));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'Channel info request failed.', false);
        }
	return $doc;

    }
    ///////////////////////////////////////////////////////////////////////

    public function try_login(&$plugin_cookies, $for_play = 'yes')
    {
        if (!isset($plugin_cookies->user_name))
            throw new Exception('User name is not set');

        try
        {
            $this->api_login(
                $plugin_cookies->user_name,
                $plugin_cookies->password,
				$for_play);

            $this->api_channel_list();
        }
        catch (Exception $e)
        {
            $this->logout();
            throw $e;
        }
    }

    public function ensure_logged_in(&$plugin_cookies, $for_play = 'yes')
    {
        if ($this->logged_in)
            return;

        $this->logout();

        $this->try_login($plugin_cookies, $for_play);
    }

    public function check_logged_in()
    {
        if (!$this->logged_in)
            throw new SStvException('Not logged in', 12);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_sid()
    {
        if (!$this->logged_in)
            throw new SStvException('Not logged in', 12);
        return $this->sid;
    }

    public function get_sid_name()
    {
        if (!$this->logged_in)
            throw new SStvException('Not logged in', 12);
        return $this->sid_name;
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_icon($id)
    {
        $archive = DefaultArchive::get_archive(
            SSTV_ARCHIVE_ID,
            SSTV_ARCHIVE_URL_PREFIX);

        return $archive->get_archive_url($id);
    }

    public function get_group_icon($group_id)
    {	
        return $this->get_icon("group_" . $group_id . $this->lang_suffix);
    }

    public function get_channel_icon($channel_id)
    {
        return $this->get_icon("channel_" . $channel_id . $this->lang_suffix);
    }

    ///////////////////////////////////////////////////////////////////////

    private function do_get_edit_subscription_defs(
        &$plugin_cookies, $handler, $add_params)
    {
        $defs = array();

        $user_name = isset($plugin_cookies->user_name) ?
            $plugin_cookies->user_name : '';
        $password = isset($plugin_cookies->password) ?
            $plugin_cookies->password : '';

        ControlFactory::add_text_field($defs,
            $handler, $add_params,
            'user_name', $this->lang->user_name,
            $user_name, true, false, false, false, 400);

        ControlFactory::add_text_field($defs,
            $handler, $add_params,
            'password', $this->lang->password,
            $password, true, true, false, false, 400);

        ControlFactory::add_vgap($defs, 50);

        ControlFactory::add_button($defs,
            $handler, $add_params,
            'apply_subscription', null, $this->lang->apply, 300);

        ControlFactory::add_vgap($defs, -3);

        ControlFactory::add_close_dialog_button($defs,
            $this->lang->cancel, 300);

        return $defs;
    }

    public function do_get_edit_subscription_action(
        &$plugin_cookies, $handler, $add_params = null)
    {
        return ActionFactory::show_dialog(
            $this->lang->login_dlg,
            $this->do_get_edit_subscription_defs(
                $plugin_cookies, $handler, $add_params),
            true);
    }

    public function apply_subscription(&$plugin_cookies, &$user_input)
    {
        if (!isset($user_input->control_id) ||
            $user_input->control_id != 'apply_subscription')
        {
            return false;
        }

        if ($user_input->user_name === '')
        {
            return array(
                'need_close_dialog' => false,
                'action' =>
                    ActionFactory::show_error(false,
                        'Error',
                        array('Subscription should be non-empty.')));
        }

        $plugin_cookies->user_name = $user_input->user_name;
        $plugin_cookies->password = $user_input->password;

        $this->logout();

        $post_action = null;
        try
        {
            $this->try_login($plugin_cookies);
        }
        catch (DuneException $e)
        {
            $post_action = $e->get_error_action();
        }

        return array(
            'need_close_dialog' => true,
            'action' => $post_action);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_archive()
    {
        return DefaultArchive::get_archive(
            SSTV_ARCHIVE_ID, SSTV_ARCHIVE_URL_PREFIX);
    }
}

///////////////////////////////////////////////////////////////////////////
?>
