<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/abstract_controls_screen.php';

///////////////////////////////////////////////////////////////////////////

class SStvSetupScreen extends AbstractControlsScreen
{
    const ID = 'setup';

    ///////////////////////////////////////////////////////////////////////

    private $session;
    private $lang;

    ///////////////////////////////////////////////////////////////////////

    public function __construct($session)
    {
        parent::__construct(self::ID);

        $this->session = $session;
        $this->lang = $session->get_lang();
    }

    private function get_http_caching_caption($value)
    {
        if ($value % 1000 == 0)
            return sprintf('%d s', intval($value / 1000));
         return sprintf('%.1f s', $value / 1000.0);
    }

    private function do_get_edit_pcode_defs()
    {
        if (isset($this->session->get_account()->pcode) && is_string($this->session->get_account()->pcode))
            $pcode = $this->session->get_account()->pcode;
        else
            $pcode = '';

        $defs = array();

        $this->add_text_field($defs,
            'current_pcode', $this->lang->current_pcode,
            '', true, true, false, false, 400);

        $this->add_text_field($defs,
            'new_pcode', $this->lang->new_pcode,
            $pcode, true, true, false, false, 400);

        $this->add_text_field($defs,
            'new_pcode_copy', $this->lang->new_pcode2,
            $pcode, true, true, false, false, 400);

        $this->add_vgap($defs, 50);

        $settings = $this->session->get_settings();

        $ar = strval($settings->ar->value);
        $ar_ops = array();
        $ar_arr = ItemsToArr($settings->ar->list->item);
        foreach ($ar_arr as $v)
            $ar_ops[$v->age] = $v->descr;
        $this->add_combobox($defs, 'ar', $this->lang->ar,
            $ar, $ar_ops, 0, true);

        $this->add_vgap($defs, 50);

        $this->add_button($defs,
            'apply_pcode', null, $this->lang->apply, 300);

        $this->add_vgap($defs, -3);

        $this->add_close_dialog_button($defs,
            $this->lang->cancel, 300);

        return $defs;
    }

    private function do_get_edit_pcode_action()
    {
        return ActionFactory::show_dialog(
            $this->lang->ar_dlg,
            $this->do_get_edit_pcode_defs(),
            true);
    }

    private function do_get_control_defs(&$plugin_cookies)
    {
        $defs = array();

        $user_name = isset($plugin_cookies->user_name) ?
            $plugin_cookies->user_name : '';

        $logged_in = $this->session->is_logged_in();

        hd_print($this->lang->packet_name .
            ($logged_in ? $this->session->get_account()->packet_name : $this->lang->unset));
        if ($user_name == '')
            $login_str = $this->lang->unset;
        else if (!$logged_in ||
            !isset($this->session->get_account()->packet_name))
        {
            $login_str = $user_name;
        }
        else
        {
            $login_str = $user_name . ' (' .
                $this->session->get_account()->packet_name . ')';
        }

        $expires_str = $this->lang->notav;
        if ($logged_in && isset($this->session->get_account()->total_expire))
        {
            $tm = $this->session->get_account()->total_expire;
            if (is_numeric($tm) && $tm > 0)
                $expires_str =
                    HD::format_date_time_date($tm) . ', ' . HD::format_date_time_time($tm);
            else if (!is_numeric($tm))
                $expires_str = $this->lang->unlim;
        }
		
		$balance_str = $this->lang->notav;
        if ($logged_in && isset($this->session->get_account()->balance))
        {
            $balance_str = $this->session->get_account()->balance;
        }
		
        $this->add_label($defs,
            $this->lang->packet_name, $login_str);

        $this->add_label($defs,
            $this->lang->expites, $expires_str);

        $this->add_label($defs,
            $this->lang->balance, $balance_str);

		$this->add_button($defs, 'edit_subscription', null,
            $this->lang->edit_subscription, 0);

		if($logged_in)
			$settings = $this->session->get_settings();
	
        if($logged_in && isset($settings))
		{
			$this->add_button($defs, 'add_money', null,
						$this->lang->add_money, 0);

			$this->add_vgap($defs, 40);
	 
			$ar = isset($settings->ar->descr) ? ' (' . $settings->ar->descr . '):' : ':';
			$this->add_button($defs, 'edit_pcode', $this->lang->prot_cont . $ar,
			$this->lang->edit, 0);
			

			$this->add_button($defs, 'edit_settings', $this->lang->parameters,
						$this->lang->edit, 0);
			
		}
		else
		{
            $this->add_label($defs, $this->lang->add_money, $this->lang->notav);
			$this->add_vgap($defs, 40);
            $this->add_label($defs, $this->lang->prot_cont, $this->lang->notav);
            $this->add_label($defs, $this->lang->parameters, $this->lang->notav);
        }

			
		$hide_icons = 0;
		if(isset($plugin_cookies->hide_icons_in_epg))
		{
			$hide_icons = $plugin_cookies->hide_icons_in_epg;
		}	
		$hide_epg_icons_ops = array();
		$hide_epg_icons_ops['0'] = $this->lang->no;
		$hide_epg_icons_ops['1'] = $this->lang->yes;
		$this->add_combobox($defs, 'hide_icons_in_epg', $this->lang->hide_icons_in_epg,
			$hide_icons, $hide_epg_icons_ops, 0, true);

		return $defs;
    }
	
    private function do_get_edit_settings_defs(&$plugin_cookies)
    {
        $defs = array();

        $logged_in = $this->session->is_logged_in();

        $settings = $this->session->get_settings();

        $bitrate_caption = $this->lang->notav;
        $http_caching_caption = $this->lang->notav;
        $fwcaching_caption = $this->lang->notav;

        
		if (isset($settings))
        {
            $bitrate = strval($settings->bitrate->value);
            $bitrate_caption = $bitrate;

            $http_caching = strval($settings->http_caching->value);
            $http_caching_caption =
                $this->get_http_caching_caption($http_caching);

            $fwcaching = strval($settings->fwcaching->value);
            $fwcaching_caption = $fwcaching;

        }

        if (isset($settings) && $logged_in)
        {

            $bitrate_ops = array();
            $bitrate_arr = ItemsToArr($settings->bitrate->list->item);
            foreach ($bitrate_arr as $v)
                $bitrate_ops[$v] = $v;
            $this->add_combobox($defs, 'bitrate', $this->lang->bitrate, $bitrate, $bitrate_ops, 0, true);

            $http_caching_ops = array();
            $http_caching_arr = ItemsToArr($settings->http_caching->list->item);
            foreach ($http_caching_arr as $v)
                $http_caching_ops[$v] = $this->get_http_caching_caption($v);
            $this->add_combobox($defs, 'http_caching', $this->lang->http_caching,
                $http_caching, $http_caching_ops, 0, true);

            $fwcaching_ops = array();
            $fwcaching_arr = ItemsToArr($settings->fwcaching->list->item);
            foreach ($fwcaching_arr as $v)
                $fwcaching_ops[strval($v)] = strval($v);
            $this->add_combobox($defs, 'fwcaching', $this->lang->fwcaching,
                $fwcaching, $fwcaching_ops, 0, true);

        }
        else
        {
            $this->add_label($defs, $this->lang->bitrate, $bitrate_caption);
            $this->add_label($defs, $this->lang->http_caching, $http_caching_caption);
            $this->add_label($defs, $this->lang->fwcaching, $fwcaching_caption);
        }

        if (isset($plugin_cookies->show_in_main_screen))
            $show_in_main_screen = $plugin_cookies->show_in_main_screen;
        else
            $show_in_main_screen = $this->lang->auto;

        $show_ops = array();
        $show_ops['auto'] = $this->lang->auto;
        $show_ops['yes'] = $this->lang->yes;
        $show_ops['no'] = $this->lang->no;
        $this->add_combobox($defs,
            'show_in_main_screen', $this->lang->show_in_main_screen,
            $show_in_main_screen, $show_ops, 0, true);

        $this->add_button($defs,
            'apply_settings', null, $this->lang->apply, 300);

        $this->add_vgap($defs, -3);

        $this->add_close_dialog_button($defs,
            $this->lang->cancel, 300);

        return $defs;
    }

    private function do_get_edit_settings_action(&$plugin_cookies)
    {
        return ActionFactory::show_dialog(
            $this->lang->parameters_dlg,
            $this->do_get_edit_settings_defs($plugin_cookies),
            true);
    }

    public function get_control_defs(MediaURL $media_url, &$plugin_cookies)
    {
        foreach($media_url as $key => $val)
			hd_print("MediaURL: $key => $val");

		try
        {
            if (!$this->session->is_login_incorrect())
                $this->session->ensure_logged_in($plugin_cookies, 'no');
        }
        catch (Exception $e)
        {
            // Nop.
        }

        return $this->do_get_control_defs($plugin_cookies);
    }

    private function do_get_enter_pincode_defs()
    {

        $defs = array();

        $this->add_text_field($defs,
            'pincode', $this->lang->pincode,
            '', true, false, false, false, 600);

        $this->add_vgap($defs, 30);

        $this->add_button($defs,
            'apply_pincode', null, $this->lang->apply, 300);

        $this->add_vgap($defs, -3);

        $this->add_close_dialog_button($defs,
            $this->lang->cancel, 300);

        return $defs;
    }

    private function do_get_add_money_action()
    {
        return ActionFactory::show_dialog(
            $this->lang->activate_paycode_dlg,
            $this->do_get_enter_pincode_defs(),
            true);
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Setup: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        $need_close_dialog = false;
        $need_reset_controls = false;
        $post_action = null;
        if ($user_input->action_type === 'apply')
        {
            $control_id = $user_input->control_id;
            if ($control_id === 'edit_subscription')
            {
                return $this->session->do_get_edit_subscription_action(
                    $plugin_cookies, $this);
            }
            else if ($control_id === 'apply_subscription')
            {
                if ($user_input->user_name === '')
                {
                    return ActionFactory::show_error(false,
                        'Error',
                        array('Subscription should be non-empty.'));
                }

                $plugin_cookies->user_name = $user_input->user_name;
                $plugin_cookies->password = $user_input->password;

                $this->session->logout();

                try
                {
                    $this->session->try_login($plugin_cookies, 'no');
                }
                catch (DuneException $e)
                {
                    $post_action = $e->get_error_action();
                }

                $need_close_dialog = true;
                $need_reset_controls = true;
            }
            else if ($control_id === 'edit_pcode')
            {
                return $this->do_get_edit_pcode_action();
            }
            else if ($control_id === 'apply_pcode')
            {
                try
                {
                    $this->session->api_change_pcode(
                        $user_input->current_pcode,
                        $user_input->new_pcode,
                        $user_input->new_pcode_copy,
                        $user_input->ar);
                }
                catch (DuneException $e)
                {
                    return $e->get_error_action();
                }

                $this->session->logout();
                try
                {
                    $this->session->try_login($plugin_cookies, 'no');
                }
                catch (DuneException $e)
                {
                    $post_action = $e->get_error_action();
                }

                $need_close_dialog = true;
                $need_reset_controls = true;
            }
            else if ($control_id === 'add_money')
            {
                return $this->do_get_add_money_action();
            }
            else if ($control_id === 'apply_pincode')
            {
				try
				{
					if (isset($user_input->pincode))
						$this->session->api_enter_pay_code($user_input->pincode);
				}
                catch (DuneException $e)
                {
                    return $e->get_error_action();
                }

				$need_close_dialog = true;
				$need_reset_controls = true;				
            }
			else if ($control_id === 'edit_settings')
			{
				return $this->do_get_edit_settings_action($plugin_cookies);
			}
			else if ($control_id === 'apply_settings')
			{
			
				if (isset($user_input->show_in_main_screen))
				{
					$plugin_cookies->show_in_main_screen = $user_input->show_in_main_screen;
					if ($user_input->show_in_main_screen === 'auto')
							$plugin_cookies->show_tv = 'yes';
					else
							$plugin_cookies->show_tv = $user_input->show_in_main_screen;
				}
				
				try
				{
					if (isset($user_input->bitrate))
						$this->session->api_set_setting('bitrate', $user_input->bitrate);
					if (isset($user_input->http_caching))
						$this->session->api_set_setting('http_caching', $user_input->http_caching);
					if (isset($user_input->fwcaching))
						$this->session->api_set_setting('fwcaching', $user_input->fwcaching);
                       
					$this->session->logout();
					try
					{
						$this->session->try_login($plugin_cookies, 'no');
					}
					catch (DuneException $e)
					{
						$post_action = $e->get_error_action();
					}
				}	
                catch (DuneException $e)
                {
                    return $e->get_error_action();
                }

				$need_close_dialog = true;
				$need_reset_controls = true;
			}
        }
		elseif($user_input->action_type === 'confirm')
		{
			if($user_input->control_id === 'hide_icons_in_epg')
			{
				$plugin_cookies->{'hide_icons_in_epg'} = $user_input->hide_icons_in_epg;
			}
		}
		
        if ($need_reset_controls)
        {
            $defs = $this->do_get_control_defs($plugin_cookies);

            $reset_controls_action = ActionFactory::reset_controls(
                $defs, $post_action);

            if ($need_close_dialog)
            {
                return ActionFactory::close_dialog_and_run(
                    $reset_controls_action);
            }

            return $reset_controls_action;
        }

        return null;
    }
}

///////////////////////////////////////////////////////////////////////////
?>
