<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/hashed_array.php';
require_once 'lib/tv/abstract_tv.php';
require_once 'lib/tv/default_epg_item.php';
require_once 'lib/tv/epg_iterator.php';

require_once 'fhtv_channel.php';

///////////////////////////////////////////////////////////////////////////

class SStvTv extends AbstractTv
{
    private $session;
    private $null_archive = false;

    ///////////////////////////////////////////////////////////////////////

    public function __construct($session)
    {
        $this->session = $session;

        parent::__construct(
            AbstractTv::MODE_CHANNELS_1_TO_N,
            true,
            false);
    }

    public function get_fav_icon_url()
    {
        return $this->session->get_icon('__favorites.png');
    }

    public function get_fav_channel_ids(&$plugin_cookies)
    {
        $fav_channel_ids = array();

        if(isset($this->session->api_favorites()->favorites->item))
        {
            $fav_arr = ItemsToArr($this->session->api_favorites()->favorites->item);
            $i = 0;
            foreach ($fav_arr as $item)
            {
                $fav_channel_ids[$i] = $item->channel_id;
                $i++;
            }
        }
        return $fav_channel_ids;
    }

    public function set_fav_channel_ids(&$plugin_cookies, &$ids)
    {

	$favorites = ItemsToArr($this->session->api_favorites()->favorites->item);
	
	// Add
	foreach($ids as $id)
	{
		$found = false;
		foreach($favorites as $item)
		{
			if($item->channel_id == $id)
			{
				$found = true;
				break;
			}
		}
		
		if(!$found)
		{
			$free_place = 1;
			foreach($favorites as $item)
				if($item->place == $free_place)
					$free_place++;
			
			$this->session->api_favorites_set($free_place, $id);
		}
	}
		
	// Remove
	foreach($favorites as $item)
	{
		if(!in_array($item->channel_id, $ids))
			$this->session->api_favorites_set($item->place, 0);
	}
	// Move
		
    }

   ///////////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////

    protected function load_channels(&$plugin_cookies)
    {
        $this->session->check_logged_in();

        $settings = $this->session->get_settings();
        $default_timeshift_hours = $settings->timeshift->value;

        $this->channels = new HashedArray();
        $this->groups = new HashedArray();

        $this->groups->put(
            new FavoritesGroup(
                $this,
                '__favorites',
                $this->session->get_lang()->favorites,
                $this->session->get_icon('__favorites.png')));

        $this->groups->put(
            new AllChannelsGroup(
                $this,
                $this->session->get_lang()->all_channels,
                $this->session->get_icon('__all.png')));

        $num_groups = 0;
        $num_channels = 0;
        $num_protected = 0;
        $num_have_archive = 0;
        $g_arr = ItemsToArr($this->session->get_channel_list()->groups->item);
        foreach ($g_arr as $g)
        {
            $g_id = intval($g->id);
            $sstv_group = new DefaultGroup(
                $g_id,
                $g->name,
                $this->session->get_group_icon($g_id));
            $this->groups->put($sstv_group);
            $num_groups++;

            $c_arr = ItemsToArr($g->channels->item);
            foreach ($c_arr as $c)
            {
                $have_archive = isset($c->have_archive) ?
                    ($c->have_archive == 'true') : false;
                $is_protected = isset($c->protected) ?
                    ($c->protected == 'true') : false;
                if ($is_protected && isset($c->ar))
                    $c_name = $c->name . ' (' . $c->ar . ')';
                else
                    $c_name = $c->name;

                // TODO: timeshift
                $timeshift_hours = 0;

                $c_id = intval($c->id);

                $sstv_channel = new SStvChannel(
                    $c_id,
                    $c_name,
                    $this->session->get_channel_icon($c_id),
                    $have_archive, $is_protected,
                    $timeshift_hours);
                $this->channels->put($sstv_channel);

                $sstv_channel->add_group($sstv_group);
                $sstv_group->add_channel($sstv_channel);

                $num_channels++;
                if ($is_protected)
                    $num_protected++;
                if ($have_archive)
                    $num_have_archive++;
            }
            $c_arr = null;
        }

        hd_print("FromHome.tv: $num_groups groups and ".
            "$num_channels channels ($num_have_archive have archive, ".
            "$num_protected protected)");
    }

    public function get_tv_info(MediaURL $media_url, &$plugin_cookies)
    {
        $this->session->ensure_logged_in($plugin_cookies);
		
		$hide_icons = false;
        if(isset($plugin_cookies->hide_icons_in_epg) and $plugin_cookies->hide_icons_in_epg == 1)
			$hide_icons = true;
		
		// don't use fhtv_86x54.bnk
		$this->null_archive = true;
		$info = parent::get_tv_info($media_url, &$plugin_cookies);
		$this->null_archive = false;
		
		if($hide_icons)
		{
			$new_channels = array();
			foreach($info[PluginTvInfo::channels] as $c)
			{
				$cid = $c[PluginTvChannel::id];
				$c[PluginTvChannel::icon_url] = 'plugin_file://icons/dummy.png';//'plugin_file://icons/transparent.png';
				array_push($new_channels, $c);
			}	
			$info[PluginTvInfo::channels] = $new_channels;
		}
		
		return $info;
    }

    ///////////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////

    public function get_tv_stream_url($playback_url, &$plugin_cookies)
    {
        return $this->session->api_get_stream_url($playback_url);
    }

    public function get_tv_playback_url($channel_id, $archive_ts, $protect_code, &$plugin_cookies)
    {
        $this->ensure_channels_loaded($plugin_cookies);

        $url = sprintf(SSTV_GET_URL_URL,
            SSTV::$SERVER,
            $this->session->get_sid_name(),
            $this->session->get_sid(),
            $channel_id);

        if (intval($archive_ts) > 0)
            $url .= "&gmt=$archive_ts";
        if (isset($protect_code) && $protect_code !== '')
            $url .= "&protect_code=$protect_code";

        return $url;
    }

    ///////////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////

    public function get_day_epg_iterator($channel_id, $day_start_ts, &$plugin_cookies)
    {
        $this->ensure_channels_loaded($plugin_cookies);

        $day_str = gmstrftime('%d%m%y', $day_start_ts);
        $url = sprintf(SSTV_EPG_URL,
            SSTV::$SERVER,
            $this->session->get_sid_name(),
            $this->session->get_sid(),
            $channel_id,
            $day_str);

        try
        {
            $sstv_epg = $this->session->api_call($url);
        }
        catch (Exception $e)
        {
            throw $this->session->dune_api_exception($e,
                'EPG request failed.',
                true);
        }

        $epg_items = array();
        if (isset($sstv_epg->epg->item))
        {
            $epg_arr = ItemsToArr($sstv_epg->epg->item);
            foreach ($epg_arr as $epg)
            {
                $epg_items[] = new DefaultEpgItem(
                    $epg->progname, is_string($epg->description) ? $epg->description : '', intval($epg->ut_start), -1);
            }
        }
        return new EpgIterator(
            $epg_items,
            $day_start_ts - 7 * 86400,
            $day_start_ts + 7 * 86400);
//        $day_start_ts = $day_start_ts - HD::get_local_time_zone_offset();
//        return new EpgIterator($epg_items, $day_start_ts, $day_start_ts + 86400);
    }

    public function get_archive(MediaURL $media_url)
    {
        if($this->null_archive)
			return null;

		return $this->session->get_archive();
    }

    public function folder_entered(MediaURL $media_url, &$plugin_cookies)
    {
        if (!isset($media_url->screen_id) ||
            $media_url->screen_id === TvGroupListScreen::ID)
        {
            $this->session->logout();
        }

        $this->session->ensure_logged_in($plugin_cookies);
    }

    // Hook for adding special group items.
    public function add_special_groups(&$items)
    {
/*        array_unshift($items,
            array
            (
                PluginRegularFolderItem::media_url =>
                    MediaURL::encode(
                        array
                        (
                            'screen_id' => SStvVodRootScreen::ID,
                        )),
                PluginRegularFolderItem::caption => 'Videoteka',
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path =>
                        $this->session->get_icon('mov_root.png')
                )
            ));
*/
    }
}

///////////////////////////////////////////////////////////////////////////
?>
