<?php

require_once 'fhtv_utils.php';

///////////////////////////////////////////////////////////////////////////

class SStvTvChannelListScreen extends TvChannelListScreen
{
    private $session;

    public function __construct($session, Tv $tv, $folder_views)
    {
        parent::__construct($tv, $folder_views);

        $this->session = $session;
    }

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        $this->session->ensure_logged_in($plugin_cookies);
        $this->tv->ensure_channels_loaded($plugin_cookies);

        return parent::get_all_folder_items($media_url, $plugin_cookies);
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('SStvTvChannelListScreen: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        if ($user_input->control_id == 'info')
        {
            if (!isset($user_input->selected_media_url))
                return null;

            $media_url = MediaURL::decode($user_input->selected_media_url);
            $channel_id = $media_url->channel_id;

            $channels = $this->tv->get_channels();
            $c = $channels->get($channel_id);
            $id = $c->get_id();
            $title = $c->get_title();

            $info = $this->session->api_channel_info($channel_id);

            $defs = array();          

            $lines = SplitString($info->description);
            for($i = 0; $i < sizeof($lines); $i++)
            {
               ControlFactory::add_label($defs, null, $lines[$i]);
               ControlFactory::add_vgap($defs, -30);
            }
            ControlFactory::add_vgap($defs, 30);
            if($info->is_radio == "true")
            	ControlFactory::add_label($defs, null, $this->session->get_lang()->radio);
            else
                ControlFactory::add_label($defs, null, $this->session->get_lang()->ar_info . '  '. $info->ar);

            ControlFactory::add_vgap($defs, 10);
            ControlFactory::add_close_dialog_button($defs, $this->session->get_lang()->close);

            return ActionFactory::show_dialog($info->name, $defs, true);
        }

        return parent::handle_user_input($user_input, $plugin_cookies);
    }

}

///////////////////////////////////////////////////////////////////////////
?>
